# Federated Agent

The Federated Agent is a thin client that allows a connection between your database and Domo.

> Before you run the agent you must do these things:
> 1. Ensure JDK 11 is in use. The "sdkman" tool is useful for this.
> 2. Set the necessary properties in application-agent.properties.
> 3. Set the necessary environment variables for the Certificate and Private Key.
> 4. Put the JDBC driver jars in the drivers folder.

### Properties

>Before you run the agent these properties must be set in application-agent.properties.

In the config folder you will find the application-agent.properties. 
Most properties have sensible defaults, but the properties below must be updated:

```
domo.domain
domo.auth.token
domo.agent.name
```

* domo.domain: Your Domo domain (Ex: company.domo.com).
* domo.auth.token: A security token that authenticates the Agent to Domo. 
  You will need to generate it in Domo under the Admin Settings > Security > Access Tokens.
* domo.agent.name: A human-readable label that will identify the Agent in the UI in Domo.

### Certificate

>Before you run the agent these environment variables must be set.

On start up the Federated Agent generates a self-signed certificate and private key that are used for RSA Encryption.
In order to generate the certificate and before you can run the Agent you'll need to provide a keystore password and private key password as environment variables.
These passwords will be used to protect the Java Key Store and Private Key respectively. They may be set to whatever you like.
These are the two environment variables:

```
DOMO_FEDERATED_KEYSTORE_PASSWORD
DOMO_FEDERATED_PRIVATE_KEY_PASSWORD
```

If you do not want to use the generated self-signed certificate you may instead provide your own certificate and private key. 
You'll need to update the keystore properties in the application-agent.properties file. 
Below are the defaults. 
If the keystore file is not found at this location and generateCertificate is set to true the Agent will attempt to generate a certificate there.

```
domo.federated.keystore.file=federated-keystore.jks
domo.federated.privatekey.alias=federated-private-key
domo.federated.certificate.alias=federated.domo.com
domo.federated.generate.certificate=true
```

### Domo Database Adapters

> Before you run the Agent your JDBC driver jars must be placed in the drivers folder.

In addition to the above configuration you'll also need to provide the JDBC driver jars for the databases you want to connect to.
The drivers folder is the default location to place these jars but if you wish to customize the location you can do so with the following property.

```
domo.drivers.folder=drivers
```

In this version of the Federated Agent the currently supported databases are:

* Amazon Athena
* Amazon Redshift
* Google BigQuery
* IBM Db2
* Microsoft Azure
* Microsoft SQL Server
* MySQL
* Oracle
* PostgreSQL
* Presto
* SAP HANA
* Snowflake (requires JDBC driver version 3.13.8 or higher)
* Teradata
* Trino
* Vertica